@@ -18,7 +18,7 @@
 #
 #    (C) 2005 Nicolas Évrard <nicoe@nutellux.be>
 
-__revision__ = "$Id: gnomolicious.py,v 1.15 2006/01/02 23:15:27 nicoe Exp $"
+__revision__ = "$Id: gnomolicious.py,v 1.16 2006/01/03 21:34:50 nicoe Exp $"
 
 import os.path
 import re
@@ -223,9 +223,9 @@ class GnomoliciousApplet(gnomeapplet.Applet):
 
     def update_tags(self):
         if (self.conf.username and self.conf.password) \
-           and (datetime.datetime.today() - self._last >= 900
+           and ((datetime.datetime.today() - self._last).seconds >= 900
                 or not list(self.tags)):
-            self._last = today()
+            self._last = datetime.datetime.today()
             logger.info('Updating your tags')
             self.tags.clear()
             taglist = self.delicious_user.tags
